@@ -1,14 +1,16 @@
 from django.contrib import admin
 
 from django_ledger.models.accounts import AccountModel
+from django_ledger.models.bank_account import BankAccountModel
 from django_ledger.models.bill import BillModel
 from django_ledger.models.coa import ChartOfAccountModel
+from django_ledger.models.customer import CustomerModel
 from django_ledger.models.entity import EntityModel, EntityManagementModel
 from django_ledger.models.invoice import InvoiceModel
 from django_ledger.models.journalentry import JournalEntryModel
 from django_ledger.models.ledger import LedgerModel
 from django_ledger.models.transactions import TransactionModel
-from django_ledger.models.bank_account import BankAccountModel
+from django_ledger.models.vendor import VendorModel
 
 
 class TransactionModelInLine(admin.TabularInline):
@@ -32,6 +34,9 @@ class EntityManagementInLine(admin.TabularInline):
 
 
 class EntityModelAdmin(admin.ModelAdmin):
+    prepopulated_fields = {
+        'slug': ('name',)
+    }
     inlines = [
         EntityManagementInLine
     ]
@@ -133,6 +138,16 @@ class BankAccountModelAdmin(admin.ModelAdmin):
         model = BankAccountModel
 
 
+class CustomerModelAdmin(admin.ModelAdmin):
+    class Meta:
+        model = CustomerModel
+
+
+class VendorModelAdmin(admin.ModelAdmin):
+    class Meta:
+        model = VendorModel
+
+
 admin.site.register(EntityModel, EntityModelAdmin)
 admin.site.register(JournalEntryModel, JournalEntryModelAdmin)
 admin.site.register(LedgerModel, LedgerModelAdmin)
@@ -141,3 +156,5 @@ admin.site.register(AccountModel, AccountModelAdmin)
 admin.site.register(InvoiceModel, InvoiceModelAdmin)
 admin.site.register(BillModel, BillModelAdmin)
 admin.site.register(BankAccountModel, BankAccountModelAdmin)
+admin.site.register(CustomerModel, CustomerModelAdmin)
+admin.site.register(VendorModel, VendorModelAdmin)
