@@ -22,16 +22,16 @@ class TransactionModelForm(ModelForm):
                 'readonly': True
             }),
             'account': Select(attrs={
-                'class': DJANGO_LEDGER_FORM_INPUT_CLASSES,
+                'class': DJANGO_LEDGER_FORM_INPUT_CLASSES + ' is-small',
             }),
             'tx_type': Select(attrs={
-                'class': DJANGO_LEDGER_FORM_INPUT_CLASSES
+                'class': DJANGO_LEDGER_FORM_INPUT_CLASSES + ' is-small',
             }),
             'amount': TextInput(attrs={
-                'class': DJANGO_LEDGER_FORM_INPUT_CLASSES
+                'class': DJANGO_LEDGER_FORM_INPUT_CLASSES + ' is-small',
             }),
             'description': TextInput(attrs={
-                'class': DJANGO_LEDGER_FORM_INPUT_CLASSES
+                'class': DJANGO_LEDGER_FORM_INPUT_CLASSES + ' is-small',
             }),
         }
 
@@ -69,7 +69,6 @@ class BaseTransactionModelFormSet(BaseModelFormSet):
         for form in self.forms:
             if self.can_delete and self._should_delete_form(form):
                 continue
-        # todo: can you use a generator?
         txs_balances = [{
             'tx_type': tx.cleaned_data.get('tx_type'),
             'amount': tx.cleaned_data.get('amount')
