@@ -8,3 +8,5 @@ from django_ledger.models.invoice import InvoiceModel
 from django_ledger.models.journalentry import JournalEntryModel
 from django_ledger.models.ledger import LedgerModel
 from django_ledger.models.transactions import TransactionModel
+from django_ledger.models.customer import CustomerModel
+from django_ledger.models.vendor import VendorModel
\ No newline at end of file
