@@ -1,9 +1,10 @@
-from datetime import timedelta, datetime
+from datetime import timedelta
 from decimal import Decimal
 
 from django.core.exceptions import ValidationError, ObjectDoesNotExist
 from django.core.validators import MinValueValidator, MaxValueValidator
 from django.db import models
+from django.utils.timezone import localdate
 from django.utils.translation import gettext_lazy as _
 
 from django_ledger.io.roles import (GROUP_INCOME, GROUP_EXPENSES,
@@ -43,6 +44,17 @@ class CreateUpdateMixIn(models.Model):
         abstract = True
 
 
+class ContactInfoMixIn(models.Model):
+    address_1 = models.CharField(max_length=70, verbose_name=_('Address Line 1'))
+    address_2 = models.CharField(null=True, blank=True, max_length=70, verbose_name=_('Address Line 2'))
+    email = models.EmailField(null=True, blank=True, verbose_name=_('Email'))
+    website = models.URLField(null=True, blank=True, verbose_name=_('Website'))
+    phone = models.CharField(max_length=30, null=True, blank=True, verbose_name=_('Phone Number'))
+
+    class Meta:
+        abstract = True
+
+
 class ProgressibleMixIn(models.Model):
     IS_DEBIT_BALANCE = None
     REL_NAME_PREFIX = None
@@ -110,7 +122,13 @@ class ProgressibleMixIn(models.Model):
         abstract = True
 
     def get_progress(self):
-        return self.progress
+        if self.progressible:
+            return self.progress
+        return (self.amount_paid or 0) / self.amount_due
+        # return Decimal(round(((self.amount_paid or 0) / self.amount_due), 2))
+
+    def get_progress_percent(self):
+        return self.get_progress() * 100
 
     def get_amount_cash(self):
         if self.IS_DEBIT_BALANCE:
@@ -169,7 +187,7 @@ class ProgressibleMixIn(models.Model):
             account = AccountModel.on_coa.for_entity_available(
                 user_model=user_model,
                 entity_slug=entity_slug
-            ).get(id=account_id)
+            ).get(uuid__exact=account_id)
         except ObjectDoesNotExist:
             raise ValidationError(f'Account ID: {account_id} may be locked or unavailable...')
         return {
@@ -207,36 +225,47 @@ class ProgressibleMixIn(models.Model):
             return tx_types[acc_bal_type + d_or_i]
         return 'debit'
 
-    def migrate_state(self, user_model, entity_slug: str, force_migrate: bool = False, commit: bool = True):
+    def migrate_state(self, user_model,
+                      entity_slug: str,
+                      force_migrate: bool = False,
+                      commit: bool = True,
+                      je_date: date = None):
+
         if self.migrate_allowed() or force_migrate:
-            txs_digest = self.ledger.digest(user_model=user_model,
-                                            process_groups=False,
-                                            process_roles=False,
-                                            process_ratios=False)
+            txs_digest = self.ledger.digest(
+                user_model=user_model,
+                process_groups=False,
+                process_roles=False,
+                process_ratios=False
+            )
 
             account_data = txs_digest['tx_digest']['accounts']
             cash_acc_db = next(
-                iter(acc for acc in account_data if acc['account_id'] == self.cash_account_id), None
+                iter(acc for acc in account_data if acc['account_uuid'] == self.cash_account_id), None
             )
             rcv_acc_db = next(
-                iter(acc for acc in account_data if acc['account_id'] == self.receivable_account_id), None
+                iter(acc for acc in account_data if acc['account_uuid'] == self.receivable_account_id), None
             )
             pay_acc_db = next(
-                iter(acc for acc in account_data if acc['account_id'] == self.payable_account_id), None
+                iter(acc for acc in account_data if acc['account_uuid'] == self.payable_account_id), None
             )
             earn_acc_db = next(
-                iter(acc for acc in account_data if acc['account_id'] == self.earnings_account_id), None
+                iter(acc for acc in account_data if acc['account_uuid'] == self.earnings_account_id), None
             )
 
-            new_state = self.new_state(commit=True)
+            new_state = self.new_state(commit=commit)
 
             diff = {
-                'amount_paid': new_state['amount_paid'] - (cash_acc_db['balance'] if cash_acc_db else 0),
-                'amount_receivable': new_state['amount_receivable'] - (rcv_acc_db['balance'] if rcv_acc_db else 0),
-                'amount_payable': new_state['amount_unearned'] - (pay_acc_db['balance'] if pay_acc_db else 0),
+                'amount_paid': round(
+                    new_state['amount_paid'] - (cash_acc_db['balance'] if cash_acc_db else 0), 2),
+                'amount_receivable': round(
+                    new_state['amount_receivable'] - (rcv_acc_db['balance'] if rcv_acc_db else 0), 2),
+                'amount_payable': round(
+                    new_state['amount_unearned'] - (pay_acc_db['balance'] if pay_acc_db else 0), 2),
                 # todo: chunk this down and figure out a cleaner way to deal with the earnings account.
                 # todo: absolute is used here because amount earned can come from an income account or expense account.
-                'amount_earned': new_state['amount_earned'] - abs(earn_acc_db['balance'] if earn_acc_db else 0)
+                'amount_earned': round(
+                    new_state['amount_earned'] - abs(earn_acc_db['balance'] if earn_acc_db else 0), 2)
             }
 
             je_txs = list()
@@ -305,8 +334,8 @@ class ProgressibleMixIn(models.Model):
                 je_txs.append(earnings_tx)
 
             if len(je_txs) > 0:
-                self.ledger.create_je_acc_id(
-                    je_date=datetime.now().date(),
+                self.ledger.commit_txs(
+                    je_date=localdate() if not je_date else je_date,
                     je_txs=je_txs,
                     je_activity='op',
                     je_posted=True,
@@ -335,11 +364,32 @@ class ProgressibleMixIn(models.Model):
         self.amount_unearned = state['amount_unearned']
         self.amount_earned = state['amount_earned']
 
+    def due_in_days(self):
+        td = self.due_date - localdate()
+        if td.days < 0:
+            return 0
+        return td.days
+
+    def is_past_due(self):
+        return not self.paid if self.paid else self.due_date < localdate()
+
+    def net_due_group(self):
+        due_in = self.due_in_days()
+        if due_in == 0:
+            return 'net_0'
+        elif due_in <= 30:
+            return 'net_30'
+        elif due_in <= 60:
+            return 'net_60'
+        elif due_in <= 90:
+            return 'net_90'
+        else:
+            return 'net_90+'
+
     def clean(self):
 
-        # todo: add validation based on income or expense scope...
         if not self.date:
-            self.date = datetime.now().date()
+            self.date = localdate()
         if self.cash_account.role != ASSET_CA_CASH:
             raise ValidationError(f'Cash account must be of role {ASSET_CA_CASH}')
         if self.receivable_account.role != ASSET_CA_RECEIVABLES:
@@ -374,8 +424,8 @@ class ProgressibleMixIn(models.Model):
         if self.paid:
             self.progress = Decimal(1.0)
             self.amount_paid = self.amount_due
+            today = localdate()
 
-            today = datetime.now().date()
             if not self.paid_date:
                 self.paid_date = today
             if self.paid_date > today:
@@ -385,16 +435,5 @@ class ProgressibleMixIn(models.Model):
         else:
             self.paid_date = None
 
-        if not self.migrate_allowed():
+        if self.migrate_allowed():
             self.update_state()
-
-
-class ContactInfoMixIn(models.Model):
-    address_1 = models.CharField(max_length=70, verbose_name=_('Address Line 1'))
-    address_2 = models.CharField(null=True, blank=True, max_length=70, verbose_name=_('Address Line 2'))
-    email = models.EmailField(null=True, blank=True, verbose_name=_('Email'))
-    website = models.URLField(null=True, blank=True, verbose_name=_('Website'))
-    phone = models.CharField(max_length=20, null=True, blank=True, verbose_name=_('Phone Number'))
-
-    class Meta:
-        abstract = True
