@@ -4,9 +4,12 @@ from django_ledger.views.bank_account import *
 from django_ledger.views.base import *
 from django_ledger.views.bill import *
 from django_ledger.views.coa import *
+from django_ledger.views.data import *
 from django_ledger.views.data_import import *
 from django_ledger.views.entity import *
 from django_ledger.views.invoice import *
 from django_ledger.views.journal_entry import *
 from django_ledger.views.ledger import *
-from django_ledger.views.txs import *
+from django_ledger.views.transactions import *
+from django_ledger.views.customer import *
+from django_ledger.views.vendor import *
