@@ -1,10 +1,13 @@
+from datetime import timedelta
+
 from django.urls import reverse
 from django.utils.translation import gettext as _
-from django.views.generic import ListView, UpdateView, CreateView
+from django.views.generic import ListView, UpdateView, CreateView, DetailView
 
 from django_ledger.forms.account import AccountModelUpdateForm, AccountModelCreateForm
 from django_ledger.models.accounts import AccountModel
 from django_ledger.models.coa import ChartOfAccountModel
+from django_ledger.utils import get_date_filter_from_session
 
 
 # Account Views ----
@@ -16,11 +19,18 @@ class AccountModelListView(ListView):
         'header_title': _('Entity Accounts')
     }
 
+    def get_context_data(self, *, object_list=None, **kwargs):
+        context = super().get_context_data(**kwargs)
+        qs = self.get_queryset()
+        context['asset_accounts'] = (a for a in qs if a.role_bs == 'assets')
+        context['liability_accounts'] = (a for a in qs if a.role_bs == 'liabilities')
+        context['equity_accounts'] = (a for a in qs if a.role_bs == 'equity')
+        return context
+
     def get_queryset(self):
         return AccountModel.on_coa.for_entity(
             entity_slug=self.kwargs['entity_slug'],
             user_model=self.request.user,
-            coa_slug=self.kwargs['coa_slug']
         ).order_by('code')
 
 
@@ -28,9 +38,7 @@ class AccountModelUpdateView(UpdateView):
     context_object_name = 'account'
     template_name = 'django_ledger/account_update.html'
     slug_url_kwarg = 'account_pk'
-
-    def get_slug_field(self):
-        return 'uuid'
+    slug_field = 'uuid'
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
@@ -39,28 +47,62 @@ class AccountModelUpdateView(UpdateView):
         return context
 
     def get_form(self, form_class=None):
-        return AccountModelUpdateForm(coa_slug=self.kwargs['coa_slug'],
-                                      entity_slug=self.kwargs['entity_slug'],
-                                      user_model=self.request.user,
-                                      **self.get_form_kwargs())
+        return AccountModelUpdateForm(
+            entity_slug=self.kwargs['entity_slug'],
+            user_model=self.request.user,
+            **self.get_form_kwargs()
+        )
 
     def get_success_url(self):
-        entity_slug = self.kwargs.get('entity_slug')
-        coa_slug = self.kwargs.get('coa_slug')
+        entity_slug = self.kwargs['entity_slug']
         return reverse('django_ledger:account-list',
                        kwargs={
                            'entity_slug': entity_slug,
-                           'coa_slug': coa_slug,
                        })
 
     def get_queryset(self):
         return AccountModel.on_coa.for_entity(
             user_model=self.request.user,
             entity_slug=self.kwargs['entity_slug'],
-            coa_slug=self.kwargs['coa_slug']
         )
 
 
+class AccountModelDetailView(DetailView):
+    context_object_name = 'account'
+    template_name = 'django_ledger/account_detail.html'
+    slug_url_kwarg = 'account_pk'
+    slug_field = 'uuid'
+    DEFAULT_TXS_DAYS = 30
+    extra_context = {
+        'DEFAULT_TXS_DAYS': DEFAULT_TXS_DAYS
+    }
+
+    def get_context_data(self, **kwargs):
+        account = self.object
+        context = super().get_context_data(**kwargs)
+        context['header_title'] = f'Account {account.code} - {account.name}'
+        context['page_title'] = f'Account {account.code} - {account.name}'
+        to_date = get_date_filter_from_session(
+            entity_slug=self.kwargs['entity_slug'],
+            request=self.request,
+        )
+        txs_qs = self.object.txs.order_by('-journal_entry__date').to_date(to_date)
+        txs_days = self.request.GET.get('txs_days')
+        if txs_days:
+            from_date = to_date - timedelta(days=int(txs_days))
+        else:
+            from_date = to_date - timedelta(days=self.DEFAULT_TXS_DAYS)
+        txs_qs = txs_qs.from_date(from_date)
+        context['transactions'] = txs_qs
+        return context
+
+    def get_queryset(self):
+        return AccountModel.on_coa.for_entity(
+            user_model=self.request.user,
+            entity_slug=self.kwargs['entity_slug'],
+        ).prefetch_related('txs')
+
+
 class AccountModelCreateView(CreateView):
     template_name = 'django_ledger/account_create.html'
 
@@ -70,9 +112,16 @@ class AccountModelCreateView(CreateView):
         context['header_title'] = _('Create Account')
         return context
 
+    def get_initial(self):
+        return {
+            'coa': ChartOfAccountModel.objects.for_entity(
+                entity_slug=self.kwargs['entity_slug'],
+                user_model=self.request.user
+            ).get(entity__slug__exact=self.kwargs['entity_slug'])
+        }
+
     def get_form(self, form_class=None):
         return AccountModelCreateForm(
-            coa_slug=self.kwargs['coa_slug'],
             user_model=self.request.user,
             entity_slug=self.kwargs['entity_slug'],
             **self.get_form_kwargs()
@@ -81,9 +130,8 @@ class AccountModelCreateView(CreateView):
     def form_valid(self, form):
         coa_model = ChartOfAccountModel.objects.for_entity(
             user_model=self.request.user,
-            coa_slug=self.kwargs['coa_slug'],
             entity_slug=self.kwargs['entity_slug']
-        ).get(slug__iexact=self.kwargs['coa_slug'])
+        ).get(entity__slug__exact=self.kwargs['entity_slug'])
         form.instance.coa = coa_model
         self.object = form.save()
         return super().form_valid(form)
@@ -99,5 +147,4 @@ class AccountModelCreateView(CreateView):
         return reverse('django_ledger:account-list',
                        kwargs={
                            'entity_slug': entity_slug,
-                           'coa_slug': coa_slug,
                        })
