@@ -1,7 +1,5 @@
-from django.http import Http404
 from django.urls import reverse
-from django.utils.translation import gettext as _
-from django.utils.translation import gettext_lazy as _l
+from django.utils.translation import gettext_lazy as _
 from django.views.generic import ListView, DetailView, UpdateView, CreateView
 
 from django_ledger.forms.ledger import LedgerModelCreateForm, LedgerModelUpdateForm
@@ -13,17 +11,12 @@ from django_ledger.models.ledger import LedgerModel
 class LedgerModelListView(ListView):
     context_object_name = 'ledgers'
     template_name = 'django_ledger/ledger_list.html'
+    PAGE_TITLE = _('Entity Ledgers')
     extra_context = {
-        'page_title': _('ledgers'),
-        'header_title': _('entity ledgers')
+        'page_title': PAGE_TITLE,
+        'header_title': PAGE_TITLE
     }
 
-    def get_context_data(self, **kwargs):
-        context = super().get_context_data(**kwargs)
-        context['page_title'] = _('entity ledgers')
-        context['header_title'] = _('entity ledgers')
-        return context
-
     def get_queryset(self):
         sort = self.request.GET.get('sort')
         if not sort:
@@ -38,30 +31,24 @@ class LedgerModelListView(ListView):
 class LedgerModelCreateView(CreateView):
     template_name = 'django_ledger/ledger_create.html'
     form_class = LedgerModelCreateForm
+    PAGE_TITLE = _('Create Ledger')
+    extra_context = {
+        'page_title': PAGE_TITLE,
+        'header_title': PAGE_TITLE
+    }
 
     def form_valid(self, form):
-        entity_qs = EntityModel.objects.for_user(user_model=self.request.user)
-        entity = entity_qs.get(slug__iexact=self.kwargs['entity_slug'])
-        form.instance.entity = entity
+        entity = EntityModel.objects.for_user(
+            user_model=self.request.user).get(slug__exact=self.kwargs['entity_slug'])
+        instance = form.save(commit=False)
+        instance.entity = entity
         self.object = form.save()
         return super().form_valid(form)
 
-    def get_context_data(self, **kwargs):
-        context = super().get_context_data(**kwargs)
-        context['page_title'] = _l('create ledger')
-        context['header_title'] = _l('create ledger')
-        return context
-
-    def get_initial(self):
-        slug = self.kwargs.get('entity_slug')
-        return {
-            'entity': EntityModel.objects.get(slug=slug)
-        }
-
     def get_success_url(self):
         return reverse('django_ledger:ledger-list',
                        kwargs={
-                           'entity_slug': self.kwargs.get('entity_slug')
+                           'entity_slug': self.kwargs['entity_slug']
                        })
 
 
@@ -70,14 +57,12 @@ class LedgerModelUpdateView(UpdateView):
     form_class = LedgerModelUpdateForm
     context_object_name = 'ledger'
     slug_url_kwarg = 'ledger_pk'
-
-    def get_slug_field(self):
-        return 'uuid'
+    slug_field = 'uuid'
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['page_title'] = _('update ledger: ') + self.object.name
-        context['header_title'] = _('update ledger: ') + self.object.name
+        context['page_title'] = _('Update Ledger: ') + self.object.name
+        context['header_title'] = context['page_title']
         return context
 
     def get_queryset(self):
@@ -98,14 +83,12 @@ class LedgerBalanceSheetView(DetailView):
     context_object_name = 'ledger'
     template_name = 'django_ledger/balance_sheet.html'
     slug_url_kwarg = 'ledger_pk'
-
-    def get_slug_field(self):
-        return 'uuid'
+    slug_field = 'uuid'
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['page_title'] = _('Ledger BS: ') + self.object.name
-        context['header_title'] = _('Ledger BS: ') + self.object.name
+        context['page_title'] = _('Ledger Balance Sheet: ') + self.object.name
+        context['header_title'] = context['page_title']
         return context
 
     def get_queryset(self):
@@ -119,14 +102,12 @@ class LedgerIncomeStatementView(DetailView):
     context_object_name = 'ledger'
     template_name = 'django_ledger/income_statement.html'
     slug_url_kwarg = 'ledger_pk'
-
-    def get_slug_field(self):
-        return 'uuid'
+    slug_field = 'uuid'
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['page_title'] = _('Ledger IC: ') + self.object.name
-        context['header_title'] = _('Ledger IC: ') + self.object.name
+        context['page_title'] = _('Ledger Income Statement: ') + self.object.name
+        context['header_title'] = context['page_title']
         return context
 
     def get_queryset(self):
